@@ -1,22 +1,22 @@
 """Module listing possible 2/3-dart finishes."""
 
 FINISHES = {
-    "41": [["9", "D16"]],
-    "42": [["10/6", "D16/D18"]],
+    "41": [["1", "D20"], ["9", "D16"]],
+    "42": [["2", "D20"], ["10", "D16"]],
     "43": [["3", "D20"], ["11", "D16"]],
-    "44": [["12", "D16"], ["4", "D20"]],
-    "45": [["13", "D16"], ["19", "D13"]],
-    "46": [["6/10", "D20/D18"]],
+    "44": [["4", "D20"], ["12", "D16"]],
+    "45": [["5", "D20"], ["13", "D16"]],
+    "46": [["6", "D20"], ["14", "D16"]],
     "47": [["7", "D20"], ["15", "D16"]],
-    "48": [["16/8", "D16/D20"]],
+    "48": [["8", "D20"], ["16", "D16"]],
     "49": [["9", "D20"], ["17", "D16"]],
     "50": [["10", "D20"], ["18", "D16"]],
     "51": [["11", "D20"], ["19", "D16"]],
     "52": [["12", "D20"], ["20", "D16"]],
     "53": [["13", "D20"], ["17", "D18"]],
-    "54": [["14", "D20"]],
-    "55": [["15", "D20"]],
-    "56": [["T16", "D4"], ["6", "DB"], ["16", "D20"]],
+    "54": [["14", "D20"], ["18", "D18"]],
+    "55": [["15", "D20"], ["19", "D18"]],
+    "56": [["16", "D20"], ["20", "D18"]],
     "57": [["17", "D20"]],
     "58": [["18", "D20"]],
     "59": [["19", "D20"]],
